@@ -31,8 +31,8 @@ our %EXPORT_TAGS = (
 
 my %EXPORT_OK;
 for my $k (keys %EXPORT_TAGS) {
-  for my $v (@{$EXPORT_TAGS{$k}}) {
-    $EXPORT_OK{$v} = 1;
+  for my $v (@{$EXPORT_TAGS{ $k }}) {
+    undef $EXPORT_OK{ $v };
   }
 }
 
@@ -43,7 +43,7 @@ $EXPORT_TAGS{ all } = [@EXPORT_OK];
 our $DIE_ON_ERROR = 0;
 our $PROMOTE_N32 = 1;
 
-our $VERSION = '3.033';
+our $VERSION = '3.034';
 
 sub IP {
   return Net::IPAddress::Util->new($_[0]);
@@ -62,6 +62,7 @@ sub new {
   }
   elsif (ref($address) eq 'ARRAY' && @$address == 4) {
     # FIXME Principal of least surprise here? Should feeding in 4 values make an IPv4?
+    # TODO At least document what it's doing, to reduce the surprise.
     $normal = [ unpack 'C16', pack 'N4', @$address ];
   }
   elsif (ref $address and eval { $address->isa(__PACKAGE__) }) {
@@ -521,7 +522,7 @@ Net::IPAddress::Util - Version-agnostic representation of an IP address
 
 =head1 VERSION
 
-Version 3.033
+Version 3.034
 
 =head1 SYNOPSIS
 
@@ -557,8 +558,8 @@ collections of addresses and/or ranges.
 
 =head2 $Net::IPAddress::Util::DIE_ON_ERROR
 
-Set to a true value to make errors confess(). Set to a false value to make
-errors cluck(). Defaults to false.
+Set to a true value to make errors C<confess()>. Set to a false value to make
+errors C<cluck()>. Defaults to false.
 
 =head2 $Net::IPAddress::Util::PROMOTE_N32
 
@@ -614,11 +615,6 @@ duplicates, so ymmv. B<There are also (rare) corner cases> in which radix_sort()
 can chew up so much RAM that it causes paging / swapping, which I<will> slow
 down the process I<dramatically>.
 
-Also note that this particular radix sort implementation is technically kinda
-C<O(48 * N)> (even though one would normally ignore a simple multiplier factor),
-so the break even point is actually nice and low (something close to 4 or more
-addresses) for it to be worth the setup and teardown costs associated.
-
 =head1 COMPATIBILITY API
 
 =head2 ip2num
@@ -632,7 +628,7 @@ addresses) for it to be worth the setup and teardown costs associated.
 =head2 fqdn
 
 These functions are exportable to provide a functionally-identical API
-to that provided by C<Net::IPAddress>. They will cause warnings to be issued
+to that provided by L<Net::IPAddress>. They will cause warnings to be issued
 if they are called, to help you in your transition to Net::IPAddress::Util,
 if indeed that's what you're doing -- and I can't readily imagine any other
 reason you'd want to export them from here (as opposed to from Net::IPAddress)
@@ -673,6 +669,63 @@ address string (e.g. '192.168.0.1' or 'fe80::1234:5678:90ab'), or based
 on what is known by this module as the "normal form", a 32-digit hex number
 (without the leading '0x').
 
+There are a number of acceptable arguments to C<new()>, though it does always
+take a single argument.
+
+=over
+
+=item 16-element ARRAYREF
+
+Creates an IPv6 object from 16 unsigned octets in network (big-endian) order.
+
+=item 4-element ARRAYREF
+
+Creates an IPv6 object from 4 unsigned 32-bit network-order integers, supplied in network order.
+
+=item An existing Net::IPAddress::Util object (equivalently, call as an object method)
+
+Creates a non-distructive clone of the object.
+
+=item A well-formed IPv4 or IPv6 string (including "IPv4 in IPv6" notation)
+
+Examples are C<1.2.3.4>, C<::ffff:1.2.3.4>, C<1:2::3:4>. Note that for IPv6
+flavor strings, the scope ID (if any) is silently discarded. Note also that this
+behavior is subject to change. If you feel strongly, go to CPAN RT and file a
+ticket.
+
+=item An unsigned 32-bit integer Perl value
+
+B<Iff> the $PROMOTE_N32 package variable is set, creates an IPv4 object.
+
+=over
+
+Actually, since I<all> objects of this class are underlyingly IPv6, creates an
+"IPv4 in IPv6" representation of the IPv4 address. This is a very minor technical
+point, but I don't want the reader going away with incorrect assumptions about
+the way this module works.
+
+=back
+
+=item An unsigned 128-bit integer Perl value (or a string holding a decimal representation of one, or a L<Math::BigInt> object containing one)
+
+Creates an IPv6 object, treating the number as network-order.
+
+=item A 32-character hex string (case insensitive)
+
+Creates an IPv6 object. B<NB> this may be especially useful when you're using
+the output of the C<normal_form> method (e.g. for round-tripping to a database).
+
+=item A non-encoded sequence of 16 bytes in Perl string form
+
+Creates an IPv6 object. B<Be especially sure> that use of this argument form is
+performed correctly. You B<MUST>, for instance, C<utf8::downgrade> and C<decode>
+your string before providing it. No effort is made to check or ensure anything
+about Unicode flagging or semantics. This is probably a bug, and is likely to be
+fixed in some future version (unless you can find a case for it being a security
+bug, in which case go directly to CPAN RT, please, and I'll fix it ASAP).
+
+=back
+
 =head2 IP
 
 The exportable function IP() is a shortcut for Net::IPAddress::Util->new().
@@ -767,4 +820,3 @@ May be redistributed and/or modified under terms of the Artistic License v2.0.
 PWBENNETT -- paul(dot)w(dot)bennett(at)gmail.com
 
 =cut
-
